package com.mdd.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.mdd.admin.service.IChannelOaCallBackService;
import com.mdd.common.entity.OfficialReply;
import com.mdd.common.exception.OperateException;
import com.mdd.common.mapper.OfficialReplyMapper;
import com.mdd.common.plugin.wechat.WxMnpDriver;
import java.util.Iterator;
import java.util.List;
import javax.annotation.Resource;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.message.WxMpXmlMessage;
import me.chanjar.weixin.mp.bean.message.WxMpXmlOutMessage;
import me.chanjar.weixin.mp.builder.outxml.TextBuilder;
import org.springframework.stereotype.Service;

@Service
public class ChannelOaCallBackServiceImpl implements IChannelOaCallBackService {
   @Resource
   private OfficialReplyMapper officialReplyMapper;

   public String checkSignature(String signature, String timestamp, String nonce, String echostr) {
      WxMpService wxMpService = WxMnpDriver.oa();
      return wxMpService.checkSignature(timestamp, nonce, signature) ? echostr : "非法请求";
   }

   public String post(String requestBody, String signature, String timestamp, String nonce, String encType, String msgSignature) {
      WxMpService wxMpService = WxMnpDriver.oa();
      if (!wxMpService.checkSignature(timestamp, nonce, signature)) {
         throw new IllegalArgumentException("非法请求，可能属于伪造的请求！");
      } else {
         String outMsg = null;
         WxMpXmlMessage inMessage;
         WxMpXmlOutMessage outMessage;
         if (encType == null) {
            inMessage = WxMpXmlMessage.fromXml(requestBody);
            outMessage = this.msgHandler(inMessage);
            if (outMessage == null) {
               return "";
            }

            outMsg = outMessage.toXml();
         } else if ("aes".equalsIgnoreCase(encType)) {
            inMessage = WxMpXmlMessage.fromEncryptedXml(requestBody, wxMpService.getWxMpConfigStorage(), timestamp, nonce, msgSignature);
            outMessage = this.msgHandler(inMessage);
            if (outMessage == null) {
               return "";
            }

            outMsg = outMessage.toEncryptedXml(wxMpService.getWxMpConfigStorage());
         }

         return outMsg;
      }
   }

   private WxMpXmlOutMessage msgHandler(WxMpXmlMessage wxMessage) {
      try {
         String msg;
         if (wxMessage.getMsgType().equals("text")) {
            msg = this.keyMsg(wxMessage);
            return this.textBuild(msg, wxMessage);
         } else if (wxMessage.getMsgType().equals("event") && wxMessage.getEvent().equals("subscribe")) {
            msg = this.subMsg();
            return this.textBuild(msg, wxMessage);
         } else {
            return null;
         }
      } catch (Exception var3) {
         Exception e = var3;
         throw new OperateException("公众号消息回调错误" + e.getMessage());
      }
   }

   private WxMpXmlOutMessage textBuild(String content, WxMpXmlMessage wxMessage) {
      return ((TextBuilder)((TextBuilder)WxMpXmlOutMessage.TEXT().content(content).fromUser(wxMessage.getToUser())).toUser(wxMessage.getFromUser())).build();
   }

   private String keyMsg(WxMpXmlMessage wxMessage) {
      List<OfficialReply> oaReplyList = this.officialReplyMapper.selectList((Wrapper)((QueryWrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).eq("reply_type", 2)).eq("is_delete", 0)).eq("status", 1)).orderByAsc("id"));
      String msg = null;
      Iterator var4 = oaReplyList.iterator();

      while(var4.hasNext()) {
         OfficialReply oaReply = (OfficialReply)var4.next();
         if (oaReply.getMatchingType() == 1 && oaReply.getKeyword().equals(wxMessage.getContent())) {
            msg = oaReply.getContent();
         }

         if (oaReply.getMatchingType() == 2 && wxMessage.getContent().contains(oaReply.getKeyword())) {
            msg = oaReply.getContent();
         }
      }

      return msg == null ? this.defaultMsg() : msg;
   }

   private String defaultMsg() {
      OfficialReply officialReply = (OfficialReply)this.officialReplyMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).eq("reply_type", 3)).eq("is_delete", 0)).eq("status", 1)).last("limit 1"));
      return officialReply == null ? null : officialReply.getContent();
   }

   private String subMsg() {
      OfficialReply officialReply = (OfficialReply)this.officialReplyMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).eq("reply_type", 1)).eq("is_delete", 0)).eq("status", 1)).last("limit 1"));
      return officialReply == null ? this.defaultMsg() : officialReply.getContent();
   }
}
